
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */


/* Generated data (by glib-mkenums) */

#ifndef __GDK_GL_ENUM_TYPES_H__
#define __GDK_GL_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gdkglconfig.h" */
GType gdk_gl_config_mode_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_CONFIG_MODE (gdk_gl_config_mode_get_type ())

/* enumerations from "gdkgltokens.h" */
GType gdk_gl_config_attrib_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_CONFIG_ATTRIB (gdk_gl_config_attrib_get_type ())
GType gdk_gl_config_caveat_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_CONFIG_CAVEAT (gdk_gl_config_caveat_get_type ())
GType gdk_gl_visual_type_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_VISUAL_TYPE (gdk_gl_visual_type_get_type ())
GType gdk_gl_transparent_type_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_TRANSPARENT_TYPE (gdk_gl_transparent_type_get_type ())
GType gdk_gl_drawable_type_mask_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_DRAWABLE_TYPE_MASK (gdk_gl_drawable_type_mask_get_type ())
GType gdk_gl_render_type_mask_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_RENDER_TYPE_MASK (gdk_gl_render_type_mask_get_type ())
GType gdk_gl_buffer_mask_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_BUFFER_MASK (gdk_gl_buffer_mask_get_type ())
GType gdk_gl_config_error_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_CONFIG_ERROR (gdk_gl_config_error_get_type ())
GType gdk_gl_render_type_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_RENDER_TYPE (gdk_gl_render_type_get_type ())
GType gdk_gl_drawable_attrib_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_DRAWABLE_ATTRIB (gdk_gl_drawable_attrib_get_type ())
GType gdk_gl_pbuffer_attrib_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_PBUFFER_ATTRIB (gdk_gl_pbuffer_attrib_get_type ())
GType gdk_gl_event_mask_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_EVENT_MASK (gdk_gl_event_mask_get_type ())
GType gdk_gl_event_type_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_EVENT_TYPE (gdk_gl_event_type_get_type ())
GType gdk_gl_drawable_type_get_type (void) G_GNUC_CONST;
#define GDK_TYPE_GL_DRAWABLE_TYPE (gdk_gl_drawable_type_get_type ())
G_END_DECLS

#endif /* __GDK_GL_ENUM_TYPES_H__ */

/* Generated data ends here */

